@@ -79,6 +79,8 @@ const (
 	ErrorResponseAssetGroupTagInvalidFields         = "position and require_certify are only allowed for tiers"
 	ErrorResponseAssetGroupTagPositionOutOfRange    = "provided tier position is out of range"
 	ErrorResponseDetailsQueryTooShort               = "search query must be at least 3 characters long"
+	ErrorResponseInvalidTagGlyph                    = "the glyph specified is invalid"
+	ErrorResponseAssetGroupTagDuplicateGlyph        = "asset group tag glyph must be unique"
 
 	FmtErrorResponseDetailsBadQueryParameters            = "there are errors in the query parameters: %v"
 	FmtErrorResponseDetailsMissingRequiredQueryParameter = "missing required query parameter: %v"
@@ -95,13 +97,7 @@ func IsErrorResponse(response *http.Response) bool {
 	return response.StatusCode < http.StatusOK || response.StatusCode >= http.StatusMultipleChoices
 }
 
-// ErrorResponse is the V1 response
-type ErrorResponse struct {
-	HTTPStatus int
-	Error      any
-}
-
-// ErrorWrapper is the V2 response
+// ErrorWrapper is the standard API response structure
 type ErrorWrapper struct {
 	HTTPStatus int            `json:"http_status"`
 	Timestamp  time.Time      `json:"timestamp"`
