@@ -39,8 +39,9 @@ import (
 	"github.com/specterops/bloodhound/cmd/api/src/model/appcfg"
 	"github.com/specterops/bloodhound/cmd/api/src/queries"
 	"github.com/specterops/bloodhound/cmd/api/src/utils/validation"
-	"github.com/specterops/bloodhound/packages/go/analysis"
 	"github.com/specterops/bloodhound/packages/go/bhlog/measure"
+	"github.com/specterops/bloodhound/packages/go/graphschema/ad"
+	"github.com/specterops/bloodhound/packages/go/graphschema/azure"
 	"github.com/specterops/bloodhound/packages/go/graphschema/common"
 	"github.com/specterops/dawgs/graph"
 	"github.com/specterops/dawgs/query"
@@ -511,17 +512,29 @@ type GetAssetGroupTagMemberCountsResponse struct {
 }
 
 func (s *Resources) GetAssetGroupTagMemberCountsByKind(response http.ResponseWriter, request *http.Request) {
+	environmentIds := request.URL.Query()[api.QueryParameterEnvironments]
+
 	if tagId, err := strconv.Atoi(mux.Vars(request)[api.URIPathVariableAssetGroupTagID]); err != nil {
 		api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusNotFound, api.ErrorResponseDetailsIDMalformed, request), response)
 	} else if tag, err := s.DB.GetAssetGroupTag(request.Context(), tagId); err != nil {
 		api.HandleDatabaseError(request, response, err)
-	} else if primaryNodeKindsCounts, err := s.GraphQuery.GetPrimaryNodeKindCounts(request.Context(), tag.ToKind()); err != nil {
-		api.HandleDatabaseError(request, response, err)
 	} else {
+		filters := []graph.Criteria{}
+		if len(environmentIds) > 0 {
+			filters = append(filters, query.Or(
+				query.In(query.NodeProperty(ad.DomainSID.String()), environmentIds),
+				query.In(query.NodeProperty(azure.TenantID.String()), environmentIds),
+			))
+		}
+
+		primaryNodeKindsCounts, err := s.GraphQuery.GetPrimaryNodeKindCounts(request.Context(), tag.ToKind(), filters...)
+		if err != nil {
+			api.HandleDatabaseError(request, response, err)
+		}
+
 		data := GetAssetGroupTagMemberCountsResponse{
 			Counts: primaryNodeKindsCounts,
 		}
-
 		for _, count := range primaryNodeKindsCounts {
 			data.TotalCount += count
 		}
@@ -531,27 +544,27 @@ func (s *Resources) GetAssetGroupTagMemberCountsByKind(response http.ResponseWri
 }
 
 type AssetGroupMember struct {
-	NodeId      graph.ID       `json:"id"`
-	ObjectID    string         `json:"object_id"`
-	PrimaryKind string         `json:"primary_kind"`
-	Name        string         `json:"name"`
-	Properties  map[string]any `json:"properties,omitempty"`
+	NodeId        graph.ID       `json:"id"`
+	ObjectID      string         `json:"object_id"`
+	EnvironmentID string         `json:"environment_id"`
+	PrimaryKind   string         `json:"primary_kind"`
+	Name          string         `json:"name"`
+	Properties    map[string]any `json:"properties,omitempty"`
 
-	Source model.AssetGroupSelectorNodeSource `json:"source,omitempty"`
+	Source          model.AssetGroupSelectorNodeSource `json:"source,omitempty"`
+	AssetGroupTagId int                                `json:"asset_group_tag_id,omitempty"`
 }
 
 // Used to minimize the response shape to just the necessary member display fields
 func nodeToAssetGroupMember(node *graph.Node, includeProperties bool) AssetGroupMember {
-	var (
-		objectID, _ = node.Properties.GetOrDefault(common.ObjectID.String(), "NO OBJECT ID").String()
-		name, _     = node.Properties.GetWithFallback(common.Name.String(), "NO NAME", common.DisplayName.String(), common.ObjectID.String()).String()
-	)
+	primaryKind, displayName, objectId, envId := model.GetAssetGroupMemberProperties(node)
 
 	member := AssetGroupMember{
-		NodeId:      node.ID,
-		ObjectID:    objectID,
-		PrimaryKind: analysis.GetNodeKindDisplayLabel(node),
-		Name:        name,
+		NodeId:        node.ID,
+		ObjectID:      objectId,
+		EnvironmentID: envId,
+		PrimaryKind:   primaryKind,
+		Name:          displayName,
 	}
 
 	if includeProperties {
@@ -600,7 +613,9 @@ func (s *Resources) GetAssetGroupTagMemberInfo(response http.ResponseWriter, req
 	} else if node, err := queries.Graph.FetchNodeByGraphId(s.GraphQuery, request.Context(), graph.ID(memberID)); err != nil {
 		api.HandleDatabaseError(request, response, err)
 	} else {
-		api.WriteBasicResponse(request.Context(), MemberInfoResponse{Member: memberInfo{nodeToAssetGroupMember(node, includeProperties), selectors}}, http.StatusOK, response)
+		groupMember := nodeToAssetGroupMember(node, includeProperties)
+		groupMember.AssetGroupTagId = assetGroupTagID
+		api.WriteBasicResponse(request.Context(), MemberInfoResponse{Member: memberInfo{groupMember, selectors}}, http.StatusOK, response)
 	}
 }
 
@@ -610,8 +625,9 @@ type GetAssetGroupMembersResponse struct {
 
 func (s *Resources) GetAssetGroupMembersByTag(response http.ResponseWriter, request *http.Request) {
 	var (
-		members     = []AssetGroupMember{}
-		queryParams = request.URL.Query()
+		members        = []AssetGroupMember{}
+		queryParams    = request.URL.Query()
+		environmentIds = queryParams[api.QueryParameterEnvironments]
 	)
 
 	if tagId, err := strconv.Atoi(mux.Vars(request)[api.URIPathVariableAssetGroupTagID]); err != nil {
@@ -628,14 +644,25 @@ func (s *Resources) GetAssetGroupMembersByTag(response http.ResponseWriter, requ
 		if len(sort) == 0 {
 			sort = query.SortItems{{SortCriteria: query.NodeID(), Direction: query.SortDirectionAscending}}
 		}
+		filters := []graph.Criteria{
+			query.KindIn(query.Node(), assetGroupTag.ToKind()),
+		}
+		if len(environmentIds) > 0 {
+			filters = append(filters, query.Or(
+				query.In(query.NodeProperty(ad.DomainSID.String()), environmentIds),
+				query.In(query.NodeProperty(azure.TenantID.String()), environmentIds),
+			))
+		}
 
-		if nodes, err := s.GraphQuery.GetFilteredAndSortedNodesPaginated(sort, query.KindIn(query.Node(), assetGroupTag.ToKind()), skip, limit); err != nil {
+		if nodes, err := s.GraphQuery.GetFilteredAndSortedNodesPaginated(sort, query.And(filters...), skip, limit); err != nil {
 			api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, fmt.Sprintf("Error getting members: %v", err), request), response)
-		} else if count, err := s.GraphQuery.CountNodesByKind(request.Context(), assetGroupTag.ToKind()); err != nil {
+		} else if count, err := s.GraphQuery.CountFilteredNodes(request.Context(), query.And(filters...)); err != nil {
 			api.WriteErrorResponse(request.Context(), api.BuildErrorResponse(http.StatusInternalServerError, fmt.Sprintf("Error getting member count: %v", err), request), response)
 		} else {
 			for _, node := range nodes {
-				members = append(members, nodeToAssetGroupMember(node, excludeProperties))
+				groupMember := nodeToAssetGroupMember(node, excludeProperties)
+				groupMember.AssetGroupTagId = assetGroupTag.ID
+				members = append(members, groupMember)
 			}
 			api.WriteResponseWrapperWithPagination(request.Context(), GetAssetGroupMembersResponse{Members: members}, limit, skip, int(count), http.StatusOK, response)
 		}
@@ -780,6 +807,7 @@ func (s *Resources) SearchAssetGroupTags(response http.ResponseWriter, request *
 			kinds  graph.Kinds
 			tagIds []int
 		)
+		tagIdByKind := make(map[graph.Kind]int)
 
 		for _, t := range tags {
 			// owned tag is a label despite distinct designation
@@ -788,6 +816,7 @@ func (s *Resources) SearchAssetGroupTags(response http.ResponseWriter, request *
 				// filter the below node and selector query to tag type
 				kinds = kinds.Add(t.ToKind())
 				tagIds = append(tagIds, t.ID)
+				tagIdByKind[t.ToKind()] = t.ID
 				if strings.Contains(strings.ToLower(t.Name), strings.ToLower(reqBody.Query)) && len(matchedTags) < assetGroupTagsSearchLimit {
 					matchedTags = append(matchedTags, t)
 				}
@@ -812,7 +841,15 @@ func (s *Resources) SearchAssetGroupTags(response http.ResponseWriter, request *
 			return
 		} else {
 			for _, node := range nodes {
-				members = append(members, nodeToAssetGroupMember(node, excludeProperties))
+				groupMember := nodeToAssetGroupMember(node, excludeProperties)
+				for _, kind := range node.Kinds {
+					// Find the first valid kind for this search type and attribute it to this member
+					if tagId, ok := tagIdByKind[kind]; ok {
+						groupMember.AssetGroupTagId = tagId
+						break
+					}
+				}
+				members = append(members, groupMember)
 			}
 		}
 
