@@ -27,19 +27,19 @@ import (
 
 	"github.com/coreos/go-oidc/v3/oidc"
 	"github.com/gorilla/mux"
-	"github.com/specterops/bloodhound/src/api"
-	"github.com/specterops/bloodhound/src/auth"
-	"github.com/specterops/bloodhound/src/config"
-	"github.com/specterops/bloodhound/src/ctx"
-	"github.com/specterops/bloodhound/src/database/mocks"
-	oidcmock "github.com/specterops/bloodhound/src/services/oidc/mocks"
+	"github.com/specterops/bloodhound/cmd/api/src/api"
+	"github.com/specterops/bloodhound/cmd/api/src/auth"
+	"github.com/specterops/bloodhound/cmd/api/src/config"
+	"github.com/specterops/bloodhound/cmd/api/src/ctx"
+	"github.com/specterops/bloodhound/cmd/api/src/database/mocks"
+	oidcmock "github.com/specterops/bloodhound/cmd/api/src/services/oidc/mocks"
 	"github.com/stretchr/testify/assert"
 
-	"github.com/specterops/bloodhound/src/api/v2/apitest"
-	v2auth "github.com/specterops/bloodhound/src/api/v2/auth"
-	"github.com/specterops/bloodhound/src/database"
-	"github.com/specterops/bloodhound/src/model"
-	"github.com/specterops/bloodhound/src/utils/test"
+	"github.com/specterops/bloodhound/cmd/api/src/api/v2/apitest"
+	v2auth "github.com/specterops/bloodhound/cmd/api/src/api/v2/auth"
+	"github.com/specterops/bloodhound/cmd/api/src/database"
+	"github.com/specterops/bloodhound/cmd/api/src/model"
+	"github.com/specterops/bloodhound/cmd/api/src/utils/test"
 	"go.uber.org/mock/gomock"
 )
 
