@@ -23,8 +23,8 @@ import (
 	"context"
 	"testing"
 
-	"github.com/specterops/bloodhound/src/model"
-	"github.com/specterops/bloodhound/src/test/integration"
+	"github.com/specterops/bloodhound/cmd/api/src/model"
+	"github.com/specterops/bloodhound/cmd/api/src/test/integration"
 	"github.com/stretchr/testify/require"
 )
 
