@@ -23,12 +23,10 @@ import {
     GraphProgress,
     GraphViewErrorAlert,
     ManageColumnsComboBoxOption,
-    MungedTableRowWithId,
     NodeClickInfo,
     WebGLDisabledAlert,
     baseGraphLayouts,
     defaultGraphLayout,
-    exportToJson,
     isNode,
     isWebGLEnabled,
     makeStoreMapFromColumnOptions,
@@ -37,7 +35,6 @@ import {
     useExploreParams,
     useExploreSelectedItem,
     useExploreTableAutoDisplay,
-    useFeatureFlag,
     useGraphHasData,
     useToggle,
 } from 'bh-shared-ui';
@@ -66,7 +63,6 @@ const GraphView: FC = () => {
     const theme = useTheme();
 
     const { data: graphHasData, isLoading, isError } = useGraphHasData();
-    const { data: tableViewFeatureFlag } = useFeatureFlag('explore_table_view');
     const { searchType } = useExploreParams();
 
     const { selectedItem, setSelectedItem, selectedItemQuery } = useExploreSelectedItem();
@@ -77,15 +73,11 @@ const GraphView: FC = () => {
     const exploreLayout = useAppSelector((state) => state.global.view.exploreLayout);
     const selectedColumns = useAppSelector((state) => state.global.view.selectedExploreTableColumns);
     const customIcons = useCustomNodeKinds({ select: transformIconDictionary });
-    let isExploreTableSelected = useAppSelector((state) => state.global.view.isExploreTableSelected);
+    const isExploreTableSelected = useAppSelector((state) => state.global.view.isExploreTableSelected);
 
     const autoDisplayTableEnabled = !exploreLayout && !isExploreTableSelected;
     const [autoDisplayTable, setAutoDisplayTable] = useExploreTableAutoDisplay(autoDisplayTableEnabled);
 
-    if (!tableViewFeatureFlag?.enabled) {
-        isExploreTableSelected = false;
-    }
-
     const graphQuery = useSigmaExploreGraph();
     // TODO: incorporate into larger hook with auto display table logic
     const displayTable = searchType === 'cypher' && (isExploreTableSelected || autoDisplayTable);
@@ -102,7 +94,7 @@ const GraphView: FC = () => {
     const isWebGLEnabledMemo = useMemo(() => isWebGLEnabled(), []);
 
     useEffect(() => {
-        let items: any = graphQuery.data?.nodes;
+        let items: any = graphQuery.data;
 
         if (!items && !graphQuery.isError) return;
         if (!items) items = {};
@@ -118,7 +110,7 @@ const GraphView: FC = () => {
         setCurrentNodes(items.nodes);
 
         setGraphologyGraph(graph);
-    }, [graphQuery.data?.nodes, theme, darkMode, graphQuery.isError, customIcons.data, displayTable]);
+    }, [graphQuery.data, theme, darkMode, graphQuery.isError, customIcons.data, displayTable]);
 
     // Changes highlighted item when browser back/forward is used
     useEffect(() => {
@@ -138,15 +130,6 @@ const GraphView: FC = () => {
         [setSelectedItem]
     );
 
-    const handleRowClick = useCallback(
-        (row: MungedTableRowWithId) => {
-            if (row.id !== selectedItem) {
-                setSelectedItem(row.id);
-            }
-        },
-        [setSelectedItem, selectedItem]
-    );
-
     const handleContextMenu = useCallback(
         (event: SigmaNodeEventPayload) => {
             selectItem(event.node);
@@ -164,12 +147,6 @@ const GraphView: FC = () => {
         [handleContextMenu]
     );
 
-    const handleDownloadClick = useCallback(() => {
-        if (graphQuery.data) {
-            exportToJson({ nodes: graphQuery.data.rawNodes });
-        }
-    }, [graphQuery.data]);
-
     if (isLoading) {
         return (
             <div className='relative h-full w-full overflow-hidden' data-testid='explore'>
@@ -269,16 +246,11 @@ const GraphView: FC = () => {
 
             <GraphProgress loading={graphQuery.isLoading} />
             <NoDataDialogWithLinks open={!graphHasData} />
-            {tableViewFeatureFlag?.enabled && displayTable && (
+            {displayTable && (
                 <ExploreTable
-                    data={graphQuery.data?.nodes}
-                    allColumnKeys={graphQuery.data.node_keys}
                     selectedColumns={selectedColumns}
                     onManageColumnsChange={handleManageColumnsChange}
                     onKebabMenuClick={handleKebabMenuClick}
-                    onDownloadClick={handleDownloadClick}
-                    onRowClick={handleRowClick}
-                    selectedNode={selectedItem}
                     onClose={() => {
                         setAutoDisplayTable(false);
                         dispatch(setIsExploreTableSelected(false));
