@@ -22,14 +22,14 @@ import (
 	"log/slog"
 	"strings"
 
-	"github.com/RoaringBitmap/roaring/roaring64"
-	"github.com/specterops/bloodhound/bhlog/measure"
-	"github.com/specterops/bloodhound/dawgs/graph"
-	"github.com/specterops/bloodhound/dawgs/ops"
-	"github.com/specterops/bloodhound/dawgs/query"
-	"github.com/specterops/bloodhound/graphschema/ad"
-	"github.com/specterops/bloodhound/graphschema/azure"
-	"github.com/specterops/bloodhound/graphschema/common"
+	"github.com/RoaringBitmap/roaring/v2/roaring64"
+	"github.com/specterops/bloodhound/packages/go/bhlog/measure"
+	"github.com/specterops/bloodhound/packages/go/graphschema/ad"
+	"github.com/specterops/bloodhound/packages/go/graphschema/azure"
+	"github.com/specterops/bloodhound/packages/go/graphschema/common"
+	"github.com/specterops/dawgs/graph"
+	"github.com/specterops/dawgs/ops"
+	"github.com/specterops/dawgs/query"
 )
 
 func FetchCollectedTenants(tx graph.Transaction) (graph.NodeSet, error) {
@@ -187,6 +187,19 @@ func FetchAzureAttackPathRoots(tx graph.Transaction, tenant *graph.Node) (graph.
 		return nil, err
 	}
 
+	// Any group or user that has an AZRoleEligible edge
+	if err := ops.ForEachStartNode(tx.Relationships().Filterf(func() graph.Criteria {
+		return query.And(
+			query.KindIn(query.Start(), azure.User, azure.Group),
+			query.Kind(query.Relationship(), azure.AZRoleEligible),
+		)
+	}), func(_ *graph.Relationship, node *graph.Node) error {
+		attackPathRoots.Add(node)
+		return nil
+	}); err != nil {
+		return nil, err
+	}
+
 	// Any ManagementGroup that contains a critical Subscription is also a critical attack path root
 	for _, criticalSubscription := range attackPathRoots.Get(azure.Subscription) {
 		walkBitmap := roaring64.New()
@@ -403,6 +416,42 @@ func FetchEntityPIMAssignments(tx graph.Transaction, node *graph.Node, skip, lim
 	})
 }
 
+func FetchRoleApprovers(tx graph.Transaction, node *graph.Node, skip, limit int) (graph.NodeSet, error) {
+	return ops.AcyclicTraverseTerminals(tx, ops.TraversalPlan{
+		Root:        node,
+		Direction:   graph.DirectionInbound,
+		Skip:        skip,
+		Limit:       limit,
+		BranchQuery: FilterRoleApprovers,
+		DescentFilter: func(ctx *ops.TraversalContext, segment *graph.PathSegment) bool {
+			if segment.Depth() == 0 && segment.Edge.Kind.Is(azure.MemberOf) {
+				return false
+			} else if segment.Depth() > 2 {
+				return false
+			} else {
+				return true
+			}
+		},
+	})
+}
+
+func FetchRoleApproverPaths(tx graph.Transaction, node *graph.Node) (graph.PathSet, error) {
+	return ops.TraversePaths(tx, ops.TraversalPlan{
+		Root:        node,
+		Direction:   graph.DirectionInbound,
+		BranchQuery: FilterRoleApprovers,
+		DescentFilter: func(ctx *ops.TraversalContext, segment *graph.PathSegment) bool {
+			if segment.Depth() == 0 && segment.Edge.Kind.Is(azure.MemberOf) {
+				return false
+			} else if segment.Depth() > 2 {
+				return false
+			} else {
+				return true
+			}
+		},
+	})
+}
+
 func FetchEntityGroupMembershipPaths(tx graph.Transaction, node *graph.Node) (graph.PathSet, error) {
 	return ops.TraversePaths(tx, ops.TraversalPlan{
 		Root:        node,
