@@ -249,6 +249,8 @@ func TestParseDomainTrusts_TrustAttributes(t *testing.T) {
 }
 
 func TestConvertComputerToNode(t *testing.T) {
+	var restrictSendingNtlmTraffic uint = 2
+
 	computer := ein.Computer{
 		IngestBase: ein.IngestBase{
 			Properties: map[string]any{
@@ -260,7 +262,7 @@ func TestConvertComputerToNode(t *testing.T) {
 				Collected: true,
 			},
 			Result: ein.NTLMRegistryInfo{
-				RestrictSendingNtlmTraffic: 2,
+				RestrictSendingNtlmTraffic: &restrictSendingNtlmTraffic,
 			},
 		},
 		IsWebClientRunning: ein.BoolAPIResult{
