@@ -34,6 +34,7 @@ import { CreateUserRequest, SSOProvider } from 'js-client-library';
 import React, { useEffect } from 'react';
 import { Controller, useForm } from 'react-hook-form';
 import { useQuery } from 'react-query';
+import { MAX_EMAIL_LENGTH, MAX_NAME_LENGTH, MIN_NAME_LENGTH } from '../../constants';
 import { apiClient } from '../../utils';
 
 export type CreateUserRequestForm = Omit<CreateUserRequest, 'SSOProviderId'> & { SSOProviderId: string | undefined };
@@ -113,6 +114,14 @@ const CreateUserForm: React.FC<{
                                     control={control}
                                     rules={{
                                         required: 'Email Address is required',
+                                        maxLength: {
+                                            value: MAX_EMAIL_LENGTH,
+                                            message: `Email address must be less than ${MAX_EMAIL_LENGTH} characters`,
+                                        },
+                                        pattern: {
+                                            value: /^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$/,
+                                            message: 'Please follow the example@domain.com format',
+                                        },
                                     }}
                                     render={({ field }) => (
                                         <TextField
@@ -136,6 +145,21 @@ const CreateUserForm: React.FC<{
                                     control={control}
                                     rules={{
                                         required: 'Principal Name is required',
+                                        maxLength: {
+                                            value: MAX_NAME_LENGTH,
+                                            message: `Principal Name must be less than ${MAX_NAME_LENGTH} characters`,
+                                        },
+                                        minLength: {
+                                            value: MIN_NAME_LENGTH,
+                                            message: `Principal Name must be ${MIN_NAME_LENGTH} characters or more`,
+                                        },
+                                        validate: (value) => {
+                                            const trimmed = value.trim();
+                                            if (value !== trimmed) {
+                                                return 'Principal Name does not allow leading or trailing spaces';
+                                            }
+                                            return true;
+                                        },
                                     }}
                                     render={({ field }) => (
                                         <TextField
@@ -157,6 +181,21 @@ const CreateUserForm: React.FC<{
                                     control={control}
                                     rules={{
                                         required: 'First Name is required',
+                                        maxLength: {
+                                            value: MAX_NAME_LENGTH,
+                                            message: `First Name must be less than ${MAX_NAME_LENGTH} characters`,
+                                        },
+                                        minLength: {
+                                            value: MIN_NAME_LENGTH,
+                                            message: `First Name must be ${MIN_NAME_LENGTH} characters or more`,
+                                        },
+                                        validate: (value) => {
+                                            const trimmed = value.trim();
+                                            if (value !== trimmed) {
+                                                return 'First Name does not allow leading or trailing spaces';
+                                            }
+                                            return true;
+                                        },
                                     }}
                                     render={({ field }) => (
                                         <TextField
@@ -178,6 +217,21 @@ const CreateUserForm: React.FC<{
                                     control={control}
                                     rules={{
                                         required: 'Last Name is required',
+                                        maxLength: {
+                                            value: MAX_NAME_LENGTH,
+                                            message: `Last Name must be less than ${MAX_NAME_LENGTH} characters`,
+                                        },
+                                        minLength: {
+                                            value: MIN_NAME_LENGTH,
+                                            message: `Last Name must be ${MIN_NAME_LENGTH} characters or more`,
+                                        },
+                                        validate: (value) => {
+                                            const trimmed = value.trim();
+                                            if (value !== trimmed) {
+                                                return 'Last Name does not allow leading or trailing spaces';
+                                            }
+                                            return true;
+                                        },
                                     }}
                                     render={({ field }) => (
                                         <TextField
@@ -235,6 +289,10 @@ const CreateUserForm: React.FC<{
                                                         message:
                                                             'Password must contain at least 1 lowercase character, 1 uppercase character, 1 number and 1 special character (!@#$%^&*)',
                                                     },
+                                                    maxLength: {
+                                                        value: 1000,
+                                                        message: 'Password must be less than 1000 characters',
+                                                    },
                                                 }}
                                                 render={({ field }) => (
                                                     <TextField
