@@ -16,14 +16,18 @@
 
 export * from './abbreviatedNumber';
 export * from './api';
+export * from './array';
 export * from './colors';
 export * from './compatibility';
 export * from './content';
 export * from './copyToClipboard';
+export * from './datePicker';
 export * from './datetime';
 export * from './entityInfoDisplay';
 export * from './exportGraphData';
+export * from './finishedJobs';
 export * from './icons';
+export * from './luxon';
 export * from './parseItemId';
 export * from './passwd';
 export * from './permissions';
