@@ -112,6 +112,8 @@ describe('Selector Form', () => {
         // The delete button should not render when creating a new selector because it doesn't exist yet
         expect(screen.queryByRole('button', { name: /Delete Selector/ })).not.toBeInTheDocument();
         expect(screen.getByRole('button', { name: /Cancel/ })).toBeInTheDocument();
+        // The save edits button should not render when creating a new selector
+        expect(screen.queryByRole('button', { name: /Save Edits/ })).not.toBeInTheDocument();
         expect(screen.getByRole('button', { name: /Save/ })).toBeInTheDocument();
 
         expect(screen.getByText('Sample Results')).toBeInTheDocument();
@@ -151,12 +153,16 @@ describe('Selector Form', () => {
         longWait(() => {
             expect(screen.getByText('Cypher Search')).toBeInTheDocument();
         });
-        // The delete button should render because this selector exists and can be deleted
+
         longWait(() => {
+            // The delete button should render because this selector exists and can be deleted
             expect(screen.getByRole('button', { name: /Delete Selector/ })).toBeInTheDocument();
+            expect(screen.getByRole('button', { name: /Cancel/ })).toBeInTheDocument();
+            // The save button should not render when editing an existing selector
+            expect(screen.queryByRole('button', { name: /Save/ })).not.toBeInTheDocument();
+            // The save edits button should render because this selector exists and can be deleted
+            expect(screen.getByRole('button', { name: /Save Edits/ })).toBeInTheDocument();
         });
-        expect(screen.getByRole('button', { name: /Cancel/ })).toBeInTheDocument();
-        expect(screen.getByRole('button', { name: /Save/ })).toBeInTheDocument();
 
         expect(screen.getByText('Sample Results')).toBeInTheDocument();
     });
