@@ -16,7 +16,7 @@
 
 import ZoneManagement from './ZoneManagement';
 
+export * from './ZoneAnalysisIcon';
 export * from './ZoneManagementContext';
-export * from './hooks';
 export * from './utils';
 export default ZoneManagement;
